Documentation
¶
Index ¶
- type AccountKeeper
- func (_m *AccountKeeper) GetAccount(ctx context.Context, addr types.AccAddress) types.AccountI
- func (_m *AccountKeeper) GetModuleAccount(ctx context.Context, name string) types.ModuleAccountI
- func (_m *AccountKeeper) GetModuleAddress(moduleName string) types.AccAddress
- func (_m *AccountKeeper) GetParams(ctx context.Context) authtypes.Params
- func (_m *AccountKeeper) NewAccountWithAddress(ctx context.Context, addr types.AccAddress) types.AccountI
- func (_m *AccountKeeper) SetAccount(ctx context.Context, acc types.AccountI)
- type BankKeeper
- func (_m *BankKeeper) IsSendEnabledCoins(ctx context.Context, coins ...types.Coin) error
- func (_m *BankKeeper) SendCoins(ctx context.Context, from types.AccAddress, to types.AccAddress, ...) error
- func (_m *BankKeeper) SendCoinsFromAccountToModule(ctx context.Context, senderAddr types.AccAddress, recipientModule string, ...) error
- func (_m *BankKeeper) SendCoinsFromModuleToAccount(ctx context.Context, senderModule string, recipientAddr types.AccAddress, ...) error
- func (_m *BankKeeper) SendCoinsFromModuleToModule(ctx context.Context, senderModule string, recipientModule string, ...) error
- type FeeMarketKeeper
- func (_m *FeeMarketKeeper) GetEnabledHeight(ctx types.Context) (int64, error)
- func (_m *FeeMarketKeeper) GetMinGasPrice(ctx types.Context, denom string) (types.DecCoin, error)
- func (_m *FeeMarketKeeper) GetParams(ctx types.Context) (feemarkettypes.Params, error)
- func (_m *FeeMarketKeeper) GetState(ctx types.Context) (feemarkettypes.State, error)
- func (_m *FeeMarketKeeper) ResolveToDenom(ctx types.Context, coin types.DecCoin, denom string) (types.DecCoin, error)
- func (_m *FeeMarketKeeper) SetParams(ctx types.Context, params feemarkettypes.Params) error
- func (_m *FeeMarketKeeper) SetState(ctx types.Context, state feemarkettypes.State) error
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type AccountKeeper ¶
AccountKeeper is an autogenerated mock type for the AccountKeeper type
func NewAccountKeeper ¶
func NewAccountKeeper(t interface {
mock.TestingT
Cleanup(func())
},
) *AccountKeeper
NewAccountKeeper creates a new instance of AccountKeeper. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*AccountKeeper) GetAccount ¶
func (_m *AccountKeeper) GetAccount(ctx context.Context, addr types.AccAddress) types.AccountI
GetAccount provides a mock function with given fields: ctx, addr
func (*AccountKeeper) GetModuleAccount ¶
func (_m *AccountKeeper) GetModuleAccount(ctx context.Context, name string) types.ModuleAccountI
GetModuleAccount provides a mock function with given fields: ctx, name
func (*AccountKeeper) GetModuleAddress ¶
func (_m *AccountKeeper) GetModuleAddress(moduleName string) types.AccAddress
GetModuleAddress provides a mock function with given fields: moduleName
func (*AccountKeeper) GetParams ¶
func (_m *AccountKeeper) GetParams(ctx context.Context) authtypes.Params
GetParams provides a mock function with given fields: ctx
func (*AccountKeeper) NewAccountWithAddress ¶
func (_m *AccountKeeper) NewAccountWithAddress(ctx context.Context, addr types.AccAddress) types.AccountI
NewAccountWithAddress provides a mock function with given fields: ctx, addr
func (*AccountKeeper) SetAccount ¶
func (_m *AccountKeeper) SetAccount(ctx context.Context, acc types.AccountI)
SetAccount provides a mock function with given fields: ctx, acc
type BankKeeper ¶
BankKeeper is an autogenerated mock type for the BankKeeper type
func NewBankKeeper ¶
func NewBankKeeper(t interface {
mock.TestingT
Cleanup(func())
},
) *BankKeeper
NewBankKeeper creates a new instance of BankKeeper. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*BankKeeper) IsSendEnabledCoins ¶
IsSendEnabledCoins provides a mock function with given fields: ctx, coins
func (*BankKeeper) SendCoins ¶
func (_m *BankKeeper) SendCoins(ctx context.Context, from types.AccAddress, to types.AccAddress, amt types.Coins) error
SendCoins provides a mock function with given fields: ctx, from, to, amt
func (*BankKeeper) SendCoinsFromAccountToModule ¶
func (_m *BankKeeper) SendCoinsFromAccountToModule(ctx context.Context, senderAddr types.AccAddress, recipientModule string, amt types.Coins) error
SendCoinsFromAccountToModule provides a mock function with given fields: ctx, senderAddr, recipientModule, amt
func (*BankKeeper) SendCoinsFromModuleToAccount ¶ added in v1.1.0
func (_m *BankKeeper) SendCoinsFromModuleToAccount(ctx context.Context, senderModule string, recipientAddr types.AccAddress, amt types.Coins) error
SendCoinsFromModuleToAccount provides a mock function with given fields: ctx, senderModule, recipientAddr, amt
func (*BankKeeper) SendCoinsFromModuleToModule ¶ added in v1.1.0
func (_m *BankKeeper) SendCoinsFromModuleToModule(ctx context.Context, senderModule string, recipientModule string, amt types.Coins) error
SendCoinsFromModuleToModule provides a mock function with given fields: ctx, senderModule, recipientModule, amt
type FeeMarketKeeper ¶
FeeMarketKeeper is an autogenerated mock type for the FeeMarketKeeper type
func NewFeeMarketKeeper ¶
func NewFeeMarketKeeper(t interface {
mock.TestingT
Cleanup(func())
},
) *FeeMarketKeeper
NewFeeMarketKeeper creates a new instance of FeeMarketKeeper. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.
func (*FeeMarketKeeper) GetEnabledHeight ¶ added in v1.1.0
func (_m *FeeMarketKeeper) GetEnabledHeight(ctx types.Context) (int64, error)
GetEnabledHeight provides a mock function with given fields: ctx
func (*FeeMarketKeeper) GetMinGasPrice ¶
GetMinGasPrice provides a mock function with given fields: ctx, denom
func (*FeeMarketKeeper) GetParams ¶
func (_m *FeeMarketKeeper) GetParams(ctx types.Context) (feemarkettypes.Params, error)
GetParams provides a mock function with given fields: ctx
func (*FeeMarketKeeper) GetState ¶
func (_m *FeeMarketKeeper) GetState(ctx types.Context) (feemarkettypes.State, error)
GetState provides a mock function with given fields: ctx
func (*FeeMarketKeeper) ResolveToDenom ¶
func (_m *FeeMarketKeeper) ResolveToDenom(ctx types.Context, coin types.DecCoin, denom string) (types.DecCoin, error)
ResolveToDenom provides a mock function with given fields: ctx, coin, denom
func (*FeeMarketKeeper) SetParams ¶
func (_m *FeeMarketKeeper) SetParams(ctx types.Context, params feemarkettypes.Params) error
SetParams provides a mock function with given fields: ctx, params
func (*FeeMarketKeeper) SetState ¶
func (_m *FeeMarketKeeper) SetState(ctx types.Context, state feemarkettypes.State) error
SetState provides a mock function with given fields: ctx, state